==> cinemaru-1.4.zip: cinemaru/language/english/admin.php <==
<?php
//%%%%%%        Admin Module Name  Headlines         %%%%%

define( '_AM_CINEMARU_DBUPDATED', "DB Updated" ) ;
define( '_AM_CINEMARU_PERMADDNG', '');
define( '_AM_CINEMARU_PERMADDOK', '');

// groupperm
define("_AM_GROUPPERM","Group Permission");

// Group's Permissions
define( '_AM_GPERM_G_INSERTABLE' , "Can add" ) ;
define( '_AM_GPERM_G_SUPERINSERT' , "Super add" ) ;
define( '_AM_GPERM_G_EDITABLE' , "Can edit" ) ;
define( '_AM_GPERM_G_SUPEREDIT' , "Super edit" ) ;
define( '_AM_GPERM_G_DELETABLE' , "Can delete" ) ;
define( '_AM_GPERM_G_SUPERDELETE' , "Super delete" ) ;
define( '_AM_GPERM_G_TOUCHOTHERS' , "Can touch others" );
define( '_AM_GPERM_G_TAGINSERTABLE' , "Can tag add" ) ;
define( '_AM_GPERM_G_TAGEDITABLE' , "Can tag edit" ) ;
define( '_AM_GPERM_G_TAGDELETABLE' , "Can tag delete" ) ;
define( '_AM_GPERM_G_VALID' , 'Movie/MP3 admission' ) ;
define( '_AM_GPERM_G_DELCOMMENT' , 'Can delete comment' ) ;
define( '_AM_GPERM_G_INSERTCOMMENT' , 'Can add comment' ) ;
define( '_AM_GPERM_G_SHOWCOMMENT' , 'Cat read comment' ) ;
define( '_AM_GPERM_G_REPORT' , 'Can repoting' ) ;
define( '_AM_GPERM_G_REPORT_LIST' , 'Can read report llist' ) ;

define( '_AM_CAT2GROUPDESC' , "Check categories which you allow to access" ) ;
define( '_AM_GROUPPERMDESC' , "Select permissions that each group is allowed to do<br />If you need this featu
re, set 'Authorities of users' to Specified in Group's permissions first.<br />The settings of two groups of A
dministrator and Guest will be ignored." ) ;

==> cinemaru-1.9.zip: cinemaru/language/english/admin.php <==
<?php
//%%%%%%        Admin Module Name  Headlines         %%%%%

define( '_AM_CINEMARU_DBUPDATED', "DB Updated" ) ;
define( '_AM_CINEMARU_PERMADDNG', '');
define( '_AM_CINEMARU_PERMADDOK', '');

// groupperm
define("_AM_GROUPPERM","Group Permission");

// Group's Permissions
define( '_AM_GPERM_G_INSERTABLE' , "Can add" ) ;
define( '_AM_GPERM_G_SUPERINSERT' , "Super add" ) ;
define( '_AM_GPERM_G_EDITABLE' , "Can edit" ) ;
define( '_AM_GPERM_G_SUPEREDIT' , "Super edit" ) ;
define( '_AM_GPERM_G_DELETABLE' , "Can delete" ) ;
define( '_AM_GPERM_G_SUPERDELETE' , "Super delete" ) ;
define( '_AM_GPERM_G_TOUCHOTHERS' , "Can touch others" );
define( '_AM_GPERM_G_TAGINSERTABLE' , "Can tag add" ) ;
define( '_AM_GPERM_G_TAGEDITABLE' , "Can tag edit" ) ;
define( '_AM_GPERM_G_TAGDELETABLE' , "Can tag delete" ) ;
define( '_AM_GPERM_G_VALID' , 'Movie/MP3 admission' ) ;
define( '_AM_GPERM_G_DELCOMMENT' , 'Can delete comment' ) ;
define( '_AM_GPERM_G_INSERTCOMMENT' , 'Can add comment' ) ;
define( '_AM_GPERM_G_SHOWCOMMENT' , 'Can read comment' ) ;
define( '_AM_GPERM_G_REPORT' , 'Can repoting' ) ;
define( '_AM_GPERM_G_REPORT_LIST' , 'Can read report llist' ) ;

define( '_AM_CAT2GROUPDESC' , "Check categories which you allow to access" ) ;
define( '_AM_GROUPPERMDESC' , "Select permissions that each group is allowed to do<br />If you need this featu
re, set 'Authorities of users' to Specified in Group's permissions first.<br />The settings of two groups of A
dministrator and Guest will be ignored." ) ;
